import { Component } from 'react'
import { Provider, ProviderProps } from 'mobx-react'
import Taro from '@tarojs/taro'
import './app.less'
// ======store======
import userInfoStore, { UserInfoStore } from './store/userInfo'
import indexStore, { IndexStore } from './store/index'
import Book, { BookStore } from './store/book'
import appInfoStore, { AppInfoStore } from './store/appInfo'
import classifyStore, { ClassifyStore } from './store/classIfy'
// ======引入全局配置======
import { initApp, setApp } from './config'
// ======引入拦截器=========
import './interceptor'
import api from './server/index'



export interface Store {
  appInfoStore: AppInfoStore
  userInfoStore: UserInfoStore,
  indexStore: IndexStore,
  bookStore: BookStore,
  classifyStore: ClassifyStore,
}
const store: Store = {
  userInfoStore,
  indexStore,
  appInfoStore,
  bookStore: Book,
  classifyStore
}
class App extends Component {

  //每次打开小程序触发，后台切入不算
  async onLaunch(options) {
  }
  componentDidMount() {
    console.log("APPcomponentDidMount")
    /**获取状态栏高度 */
    Taro.getSystemInfo({}).then(res => {
      let { system, statusBarHeight } = res
      indexStore.setData({ navBarTop: statusBarHeight, system })//设置navbar高度和当前系统
      setApp({ system })
    })
  }
  async componentDidShow(options) {
    let { scene, query } = options//获取当前小程序进入的场景值
    let bookConfig = Taro.getStorageSync("bookConfig")
    if (bookConfig) {
      Book.setData({ bookConfig: JSON.parse(bookConfig) })
    }
    indexStore.setData({ scene, query })
    // 启动初始化
    console.log("初始化")
    initApp()//初始化全局变量
    let appId = Taro.getAccountInfoSync().miniProgram.appId//获取当前小程序的APPID 
    setApp({ appId })
    // 初始化登录,获取登录使用的token存放用于登录使用
    await api.loginInit(appId)
  }
  componentDidHide() { }

  componentDidCatchError() { }

  render() {
    return <Provider store={store}>
      {(this.props as ProviderProps).children}
    </Provider>
  }
}

export default App
